@@ -20,10 +20,15 @@ data CSize = CSize Double | CFit
 type CXy = (CPosition, CPosition)
 type CWl = (CSize, CSize)
 
+fontNameP, fontNameM :: String
+fontNameP = "Noto Sans CJK JP"
+fontNameM = "Noto Sans Mono CJK JP"
+
 toDouble :: Integral a => a -> Double
 toDouble = fromIntegral
 
-type LayoutFunc = G.PangoLayout -> G.Markup -> IO ()
+-- type LayoutFunc = G.PangoLayout -> G.Markup -> IO ()
+type LayoutFunc = G.PangoLayout -> String -> IO ()
 type LayoutFuncGlowing = String -> CXy -> Double -> String -> IO (G.PangoLayout, G.PangoLayout, Double, Double)
 
 stringToLayout :: String -> LayoutFunc -> CXy -> Double -> String -> IO (G.PangoLayout, Double, Double)
@@ -75,25 +80,29 @@ renderLayout' fname func (x, y) fsize text = do
 
 renderLayoutM :: CXy -> Double -> String -> C.Render Double
 renderLayoutM = 
-  renderLayout' "IPA P明朝" (stringToLayoutGlowing fb ff)
+  renderLayout' fontNameP (stringToLayoutGlowing fb ff)
   where
-    fb l t = void $ G.layoutSetMarkup l ("<span foreground=\"white\">" ++ G.escapeMarkup t ++ "</span>")
+    fb l t = do _ <- G.layoutSetMarkup l ("<span foreground=\"white\">" ++ G.escapeMarkup t ++ "</span>") :: IO String
+                return ()
     ff = G.layoutSetText
 
 renderLayoutG' :: LayoutFuncGlowing -> CXy -> Double -> String -> C.Render Double
-renderLayoutG' = renderLayout' "IPAゴシック"
+renderLayoutG' = renderLayout' fontNameM
 
 renderLayoutG :: Attr -> CXy -> Double -> String -> C.Render Double
 renderLayoutG (_, [], _) = 
   renderLayoutG' (stringToLayoutGlowing fb ff)
   where
-    fb l t = void $ G.layoutSetMarkup l ("<span foreground=\"white\">" ++ G.escapeMarkup t ++ "</span>")
+    fb l t = do _ <- G.layoutSetMarkup l ("<span foreground=\"white\">" ++ G.escapeMarkup t ++ "</span>") :: IO String
+                return ()
     ff = G.layoutSetText
 renderLayoutG (_, classs, _) =
   renderLayoutG' (stringToLayoutGlowing fb ff)
   where
-    fb l t = void $ G.layoutSetMarkup l (formatPangoMarkupWhite (head classs) t)
-    ff l t = void $ G.layoutSetMarkup l (formatPangoMarkup (head classs) t)
+    fb l t = do _ <- G.layoutSetMarkup l (formatPangoMarkupWhite (head classs) t) :: IO String
+                return ()
+    ff l t = do _ <- G.layoutSetMarkup l (formatPangoMarkup (head classs) t) :: IO String
+                return ()
 
 renderSurface :: Double -> Double -> Double -> C.Surface -> C.Render ()
 renderSurface x y alpha surface = do
